@@ -258,7 +258,7 @@ impl Lexer {
                 "limit" => Some(Lexeme::Limit),
                 "into" => Some(Lexeme::Into),
                 "eq" | "ne" | "gt" | "lt" | "ge" | "le" | "gte" | "lte" | "regexp" | "rx"
-                | "like" | "between" | "in" => Some(Lexeme::Operator(s)),
+                | "like" | "between" | "in" | "exists" => Some(Lexeme::Operator(s.to_lowercase())),
                 "mul" | "div" | "mod" | "plus" | "minus" => Some(Lexeme::ArithmeticOperator(s)),
                 _ => Some(Lexeme::RawString(s)),
             },
@@ -302,7 +302,7 @@ static DATE_ALIKE_REGEX: LazyLock<Regex> = LazyLock::new(|| {
 
 fn looks_like_expression(s: &str) -> bool {
     !s.split(|c: char| !c.is_ascii_alphanumeric()).any(|s| {
-        Field::from_str(s).is_err() && Function::from_str(s).is_err() && s.parse::<i64>().is_err()
+        Field::parse_field(s).is_err() && Function::from_str(s).is_err() && s.parse::<i64>().is_err()
     })
 }
 
