@@ -29,8 +29,8 @@ use crate::output::OutputFormat;
 use crate::parser::Parser;
 use crate::query::RootOptions;
 use crate::searcher::Searcher;
-use crate::util::{error_exit, error_message};
 use crate::util::str_to_bool;
+use crate::util::error_message;
 
 mod config;
 mod expr;
@@ -178,7 +178,7 @@ fn main() -> ExitCode {
                     }
                     Ok(query) => {
                         let _ = rl.add_history_entry(query.as_str());
-                        exec_search(vec![query], &mut config, &default_config, no_color);
+                        exec_search(vec![query], &mut config, &default_config, no_color, true);
                     }
                     Err(ReadlineError::Interrupted) => {
                         println!("CTRL-C");
@@ -201,7 +201,7 @@ fn main() -> ExitCode {
             }
         }
     } else {
-        exit_value = Some(exec_search(args, &mut config, &default_config, no_color));
+        exit_value = Some(exec_search(args, &mut config, &default_config, no_color, false));
     }
 
     config.save();
@@ -225,7 +225,7 @@ fn main() -> ExitCode {
     ExitCode::SUCCESS
 }
 
-fn exec_search(query: Vec<String>, config: &mut Config, default_config: &Config, no_color: bool) -> u8 {
+fn exec_search(query: Vec<String>, config: &mut Config, default_config: &Config, no_color: bool, interactive: bool) -> u8 {
     if config.debug {
         dbg!(&query);
     }
@@ -239,7 +239,11 @@ fn exec_search(query: Vec<String>, config: &mut Config, default_config: &Config,
     }
 
     if parser.there_are_remaining_lexemes() {
-        error_exit("query", "could not parse tokens at the end of the query");
+        error_message("query", "could not parse tokens at the end of the query");
+
+        if !interactive {
+            std::process::exit(2);
+        }
     }
 
     match query {
@@ -371,6 +375,7 @@ Expressions:
         notlike                     Used to check if the column value doesn't match the pattern which follows SQL conventions
         between                     Used to check if the column value lies between two values inclusive
         in                          Used to check if the column value is in the list of values
+        exists                      Used to check if there is results in the subquery (optionally bound with the main query)
     Logical Operators:
         and                         Used as an AND operator for two conditions made with the above operators
         or                          Used as an OR operator for two conditions made with the above operators
