@@ -33,6 +33,7 @@ use sha1::Digest;
 
 pub use self::datetime::format_date;
 pub use self::datetime::format_datetime;
+pub use self::datetime::format_time;
 pub use self::datetime::parse_datetime;
 pub use self::datetime::to_local_datetime;
 pub use self::glob::convert_glob_to_pattern;
@@ -174,7 +175,7 @@ pub fn path_error_message(p: &Path, e: io::Error) {
 }
 
 pub fn error_message(source: &str, description: &str) {
-    eprint!("{}: {}", source, description);
+    eprintln!("{}: {}", source, description);
 }
 
 pub fn error_exit(source: &str, description: &str) -> ! {
@@ -189,6 +190,13 @@ pub fn get_extension(s: &str) -> String {
     }
 }
 
+pub fn get_stem(s: &str) -> String {
+    match Path::new(s).file_stem() {
+        Some(stem) => stem.to_string_lossy().to_string(),
+        None => String::new(),
+    }
+}
+
 pub fn parse_filesize(s: &str) -> Option<u64> {
     let string = s.to_string().to_ascii_lowercase().replace(" ", "");
     let length = string.len();
